.. _api_reference:

=============
API reference
=============

Welcome to the API reference for ``skchange``.

The API reference provides a technical manual.
It describes the classes and functions included in skchange.

For Python Interactive examples, see the `interactive <https://github.com/NorskRegnesentral/skchange/tree/main/interactive>`_ folder on Github.

.. include:: includes/api_css.rst

.. toctree::
   :maxdepth: 1

   api_reference/base
   api_reference/anomaly_detectors
   api_reference/change_detectors
   api_reference/scores
   api_reference/costs
   api_reference/datasets
   api_reference/utils
